<?php

require_once("../public/script/Connection.php");
require_once("quizEntity.php");

class QuizGateway {
    private Connection $co;

    public function __construct(Connection $co)
    {
        $this -> co = $co;
    }

    public function create(QuizEntity $q) : bool
    {
        $query = "
            INSERT INTO Quiz
            VALUES (:id_quiz, :level, :timer)
        ";

        return $this -> co -> executeQuery($query, [
            ':id_quiz' => array($q -> getIdQuiz(), PDO::PARAM_INT),
            ':level' => array($q -> getLevel(), PDO::PARAM_INT),
            ':timer' => array($q -> getTimer(), PDO::PARAM_INT)
        ]);
    }

    public function findQuizById(int $id) : ?QuizEntity
    {
        $query = "SELECT * FROM Quiz WHERE id_quiz = :id_q";

        $this->co->executeQuery($query, [':id_q' => $id]);

        $res = $this->co->getResults();

        if ($res)
            return new QuizEntity(
                $res['id_quiz'],
                $res['level'],
                $res['timer']
            );
        return null;
    }

    public function updateLevel(QuizEntity $q) : bool
    {
        $query = "
            UPDATE Quiz
            SET level = :level
            WHERE id_quiz = :id_q
        ";

        return $this -> co -> executeQuery($query, [
            ':id_q' => array($q -> getIdQuiz(), PDO::PARAM_INT),
            ':level' => array($q -> getLevel(), PDO::PARAM_INT),
        ]);
    }

    public function updateTimer(QuizEntity $q) : bool
    {
        $query = "
            UPDATE Quiz
            SET timer = :timer
            WHERE id_quiz = :id_q
        ";

        return $this -> co -> executeQuery($query, [
            ':id_q' => array($q -> getIdQuiz(), PDO::PARAM_INT),
            ':timer' => array($q -> getTimer(), PDO::PARAM_INT),
        ]);
    }

    public function delete(int $id) : bool
    {
        $query = "DELETE FROM Quiz WHERE id_quiz = :id_q";

        return $this -> co -> executeQuery($query, [':id_q' => $id]);
    }

    public function findAll() : array
    {
        $query = "SELECT * FROM Quiz";

        $this -> co -> executeQuery($query);

        $res = $this -> co -> getResults();

        $quiz = [];

        foreach ($res as $q)
            $quiz[] = new QuizEntity(
                $q['id_quiz'],
                $q['level'],
                $q['timer']
            );

        return $quiz;
    }

}